const state = {
    cartItems: {
        default: [],
        values: []
    },
    cartTotal: {
        default: 0,
        value: 0
    }
}

const getters = {
    /**
     * 
     * @param {*} state 
     */
    cartItems(state) {
        return state.cartItems.values
    },
    /**
     * 
     * @param {*} state 
     */
    total(state) {
        return state.cartTotal.value
    }
}

const mutations = {
    /**
     * 
     * @param {*} state 
     * @param {*} payload 
     */
    setCartItems(state, payload) {
        state.cartItems.values = [...payload]
    },
    /**
     * 
     * @param {*} state 
     * @param {*} payload 
     */
    setTotal(state, payload) {
        state.cartTotal.value = payload
    },
    /**
     * 
     * @param {*} state 
     * @param {*} payload 
     */
    addToCart(state, payload) {
        let productFound = state.cartItems.values.find(item => item.id === payload.id)

        if(productFound) {
            payload.qty = payload.qty + 1
            return
        }

        state.cartItems.values = [payload, ...state.cartItems.values]
    },
    /**
     * 
     * @param {*} state 
     */
    computeTotal(state) {
        console.log(state.cartTotal)
        state.cartTotal.value = state.cartItems.values.reduce((total, value) => total + ((value.price || value.listPrice) * (value.qty || 1)), 0)
    }
}

const actions = {
    /**
     * Add item to cart or increment item quantity if exist
     * @param {*} param0 
     * @param {*} payload 
     */
    addToCart({ commit }, payload) {
        commit('addToCart', payload)
        commit('computeTotal')
    },
    /**
     * Remove item from cart
     * @param {*} param0 
     * @param {*} payload 
     */
    removeFromCart({ commit }, payload) {
        console.log(payload)
    },
    /**
     * Decrement item quantity from cart
     * @param {*} param0 
     * @param {*} payload 
     */
    decrementFromCart({ commit }, payload) {
        console.log(payload)
    }
}

export default {
    state,
    getters,
    mutations,
    actions
}